==> pyrez-1.1.0.3.1-py2.py3-none-any.whl: pyrez/enumerations/AvatarPaladins.py <==
from .Enum import Enum
class AvatarPaladins(Enum):
    Default = 0
    Origin = 9918
    Cosplay = 23120
    VIP = 23203
    Striker = 23209
    Terminating = 23226
    Corrupter = 23442
    The_Lost_Hand = 23549
    Oni_Mask = 23550
    Cutesy_Maeve = 23552
    Cutesy_Snek = 23553
    Cutest_Zhin = 23554
    Goodnight = 23555
    Shadowblade = 23564
    Flametongue = 23661
    Snack_Time = 23662
    Death_Speaker = 23714
    Knightmare = 23715
    Day_Walker = 23716
    Harbinger = 23717
    Synth = 23924
    Nom_Nom = 23925
    Cutesy_Yeti = 24079
    Cutesy_Lian = 24080
    Rowdy_Corsair = 24081
    Winter_Workout = 24088
    Suit_Up = 24120
    Shield_Bearer = 24143
    The_King = 24164
    Poppy = 24165
    Greenwood_Friend = 24166
    White_Knight = 24167
    Masterpiece = 24168
    Battle_Rage = 24169
    Groverling = 24170
    Forkasen_Wanderer = 24171
    Kitten = 24172
    Tigron_Thief = 24173
    I_WUV_YOU = 24174
    Tepid_Friendship = 24175
    Vulpin = 24176
    Dumpster_Diver = 24177
    Abyssal_Vessel = 24178
    The_Returned = 24179
    Twilight_Assassin = 24180
    Happy_Huntress = 24181
    The_Blossom = 24182
    Mirror_Mirror = 24183
    Paladins_Defense_Force = 24202
    Imperial_Magistrate = 24203
    Fire_and_Ice = 24204
    Queen_of_Hearts = 24350
    Futures_Protector = 24354#Future's Protector
    Assembly_of_Champion = 24241
    Squidly = 24355
    Forlorn_Future = 24356
    Dragon_Queen = 24375
    Diamond_Bagde = 24393
    Gold_Bagde = 24394
    Blue_Warrior = 24482
    How_Quaint = 24505
    Champions_are_Eternal = 24597
    Best_Boy = 24611
    Summer_Blossom = 24612
    Vanguard = 24669
    Bubbles = 24678
    Baby_Steps = 24679
    Dragon_Forged = 24680
    Dwarven_Strength = 24681
    Unrelenting = 24709
    Charming = 24758
    Sunset = 24759
    Lifesaver = 24760
    Beach_Vibes = 24824
    Groovy_Grover = 24887
    Grohk_Rock = 24888
    Celebrity_Io = 24889
    Popstar_Skye = 24890
    Greaser_Lex = 24891
    Fallen_Champion = 24892
    Reckoning = 24897
    Resolute = 24898
    Redbeard = 24969
    Bubbly = 24970
    Pirateer = 24972
    Kitsune = 24973
    Blu = 25021
    Molly_the_Shark = 25022
    Suave_Saguaro = 25138
    Wanted_Man = 25139
    Bandits_Fury = 25140
    Smoked = 25141
    Lenny_the_Pirate = 25161
    Goddess_of_Death = 25222
    Skadrin_Ash = 25223
    Dark_Monarch = 25224
    Soul_Briar = 25225
    Wukong = 25226
    Mischievous = 25227
    Forest_Protector = 25228
    Ice_Box = 25229
    Charity_Avatar_Community_Patch = 25342
    Adanas_the_Balance_Master = 25355
    Gentleman_Raum = 25356
    Tyra_nova = 25357
    Four_Leaf_Grover = 25421
    Termineaster = 25422
    Temple_Guardian = 25434
    Devious = 25435
    Divine_Priestess = 25437
    The_Risen = 25438
    Scaled_Menace = 25506
    Hunters_Fury = 25507
    Survivor = 26291

==> pyrez-1.1.1.1-py2.py3-none-any.whl: pyrez/enumerations/AvatarPaladins.py <==
from .Enum import Enum
class AvatarPaladins(Enum):
    Default = 0
    Origin = 9918
    Cosplay = 23120
    VIP = 23203
    Striker = 23209
    Terminating = 23226
    Corrupter = 23442
    The_Lost_Hand = 23549
    Oni_Mask = 23550
    Cutesy_Maeve = 23552
    Cutesy_Snek = 23553
    Cutest_Zhin = 23554
    Goodnight = 23555
    Shadowblade = 23564
    Flametongue = 23661
    Snack_Time = 23662
    Death_Speaker = 23714
    Knightmare = 23715
    Day_Walker = 23716
    Harbinger = 23717
    Synth = 23924
    Nom_Nom = 23925
    Cutesy_Yeti = 24079
    Cutesy_Lian = 24080
    Rowdy_Corsair = 24081
    Winter_Workout = 24088
    Suit_Up = 24120
    Shield_Bearer = 24143
    The_King = 24164
    Poppy = 24165
    Greenwood_Friend = 24166
    White_Knight = 24167
    Masterpiece = 24168
    Battle_Rage = 24169
    Groverling = 24170
    Forkasen_Wanderer = 24171
    Kitten = 24172
    Tigron_Thief = 24173
    I_WUV_YOU = 24174
    Tepid_Friendship = 24175
    Vulpin = 24176
    Dumpster_Diver = 24177
    Abyssal_Vessel = 24178
    The_Returned = 24179
    Twilight_Assassin = 24180
    Happy_Huntress = 24181
    The_Blossom = 24182
    Mirror_Mirror = 24183
    Paladins_Defense_Force = 24202
    Imperial_Magistrate = 24203
    Fire_and_Ice = 24204
    Assembly_of_Champions = 24241
    Queen_of_Hearts = 24350
    Futures_Protector = 24354#Future's Protector
    Squidly = 24355
    Forlorn_Future = 24356
    Dragon_Queen = 24375
    Diamond_Bagde = 24393
    Gold_Bagde = 24394
    Blue_Warrior = 24482
    How_Quaint = 24505
    Champions_are_Eternal = 24597
    Best_Boy = 24611
    Summer_Blossom = 24612
    Vanguard = 24669
    Bubbles = 24678
    Baby_Steps = 24679
    Dragon_Forged = 24680
    Dwarven_Strength = 24681
    Unrelenting = 24709
    Charming = 24758
    Sunset = 24759
    Lifesaver = 24760
    Beach_Vibes = 24824
    Groovy_Grover = 24887
    Grohk_Rock = 24888
    Celebrity_Io = 24889
    Popstar_Skye = 24890
    Greaser_Lex = 24891
    Fallen_Champion = 24892
    Reckoning = 24897
    Resolute = 24898
    Redbeard = 24969
    Bubbly = 24970
    Pirateer = 24972
    Kitsune = 24973
    Blu = 25021
    Molly_the_Shark = 25022
    Suave_Saguaro = 25138
    Wanted_Man = 25139
    Bandits_Fury = 25140
    Smoked = 25141
    Lenny_the_Pirate = 25161
    Goddess_of_Death = 25222
    Skadrin_Ash = 25223
    Dark_Monarch = 25224
    Soul_Briar = 25225
    Wukong = 25226
    Mischievous = 25227
    Forest_Protector = 25228
    Ice_Box = 25229
    Charity_Avatar_Community_Patch = 25342
    Adanas_the_Balance_Master = 25355
    Gentleman_Raum = 25356
    Tyra_nova = 25357
    Four_Leaf_Grover = 25421
    Termineaster = 25422
    Temple_Guardian = 25434
    Devious = 25435
    Divine_Priestess = 25437
    The_Risen = 25438
    Scaled_Menace = 25506
    Hunters_Fury = 25507
    Brood_Guard = 25545
    Eye_of_Saurus = 25546
    Survivor = 26291
    Captains_Guile = 26325
    Unstable_Power = 26326
    Devotion = 26346
    Spirit = 26347
    Determination = 26348
    Passion = 26349
    Serene = 26350
    Starry_Eyed = 26351
    Under_the_Sea = 26352
    LGBTQIA_Pride = 26510
    Winner_Winner = 26521
    Blazing_Spirit = 26759
    Dark_Gaze = 26760
    Lily_hopper = 26761
    Knowledge_Seeker = 26762
    Trailblazer = 26763
    Ember = 26764
    Festive_Menorah = 26769
    First_Fruits = 26770
    Holiday_Cheer = 26771
    Ruckus_New_Year = 26772
    Beevie = 26774
    Harbinger_of_the_End = 26776
    Bisexual_Pride = 26779
    Asexual_Pride = 26780
    Transgender_Pride = 26781
    Non_Binary_Pride = 26782
    Lesbian_Pride = 26783
    Pansexual_Pride = 26784
    Dark_Deeds = 26875
    Beauty_in_Conflict = 26876
    Relic_of_Salvation = 26877
    Penitence = 26878
    Uplifting_Grace = 26879
    Self_Sufficient = 26967
    The_Maw = 26969
    Lunar_New_Year = 26974
    Will_U_B_Mine = 26976
